<?php

// class for getting wordpress content
// get list of all kinds of post types: ex. post, page, custom post types

class Web_Content {

    public function __constructor() {
        // do nothing
    }

    // get total number of posts
    public function get_total_posts() {
        $args = array(
            'post_type' => 'post',
            'posts_per_page' => -1,
            'post_status' => 'publish'
        );
        $posts = new WP_Query($args);
        return $posts->found_posts;
    }

    // get total number of pages
    public function get_total_pages() {
        $args = array(
            'post_type' => 'page',
            'posts_per_page' => -1,
            'post_status' => 'publish'
        );
        $pages = new WP_Query($args);
        return $pages->found_posts;
    }

    // get total number of products
    public function get_total_products() {
        $args = array(
            'post_type' => array('product'),
            'posts_per_page' => -1,
            'post_status' => 'publish'
        );
        $products = new WP_Query($args);
        return $products->found_posts;
    }

    // get all posts
    public function get_all_posts($page = 1, $per_page = 15) {
        $args = array(
            'post_type' => 'post',
            'post_status' => 'publish',
            'posts_per_page' => $per_page,
            'paged' => $page
        );
        $posts = get_posts($args);
        return $posts;
    }

    
    // get all pages
    public function get_all_pages($page = 1, $per_page = 15) {
        $args = array(
            'post_type' => 'page',
            'post_status' => 'publish',
            'posts_per_page' => $per_page,
            'paged' => $page
        );
        $pages = get_posts($args);
        return $pages;
    }

    // get all products in woocommerce
    public function get_all_products($page = 1, $per_page = 15) {
        $args = array(
            'post_type' => 'product',
            'post_status' => 'publish',
            'posts_per_page' => $per_page,
            'paged' => $page
        );
        $products = get_posts($args);
        return $products;
    }

    // get all post types except products, posts and pages
    public function get_all_custom_post_types() {
        // Get all public post types
        $post_types = get_post_types( array( 'public' => true ), 'names' );

        // Remove 'product' from the array
        unset( $post_types['product'] );
        unset( $post_types['page'] );
        unset( $post_types['post'] );

        // Output or work with the post types
        $post_types = array();
        foreach ( $post_types as $post_type ) {
            $post_types[] = $post_type;
        };

        return $post_types;
    }

    // get all post types except products, posts and pages
    public function get_all_custom_contents($page, $max_per_page = 50) {
        $post_types = $this->get_all_custom_post_types();

        $args = array(
            'post_type' => $post_types,
            'post_status' => 'publish',
            'posts_per_page' => $max_per_page,
            'paged' => $page
        );

        $custom_contents = get_posts($args);
        return $custom_contents;
    }
}